===== 
MPrint Assistant
===== 
Intro
-------- 
MPrint Assistant gives command line users a simple, fast way to print documents to University of Michigan printers. Unlike the browser MPrint interface, MPrint Assistant allows multiple documents to be simultaneously selected and sent to a printer.

Features include:

- Batch printing
- Building search by name, acronym
- Tab completion for buildings, document paths
- Flags that allow for fast usage

Installation
--------
Install using pip:

    pip install mprint-assistant
    
A runnable script called ``mprint`` will be placed in your path (/usr/local/bin/mprint).

